@@ -1,17 +1,16 @@
 from pathlib import Path
-from typing import Callable, Dict, Optional, Type, Union
+from typing import Callable, Dict, Optional, Type, Union, Tuple
 import logging
 
 from .adapters.aiosqlite import AioSQLiteAdapter
 from .adapters.asyncpg import AsyncPGAdapter
-from .adapters.psycopg import PsycoPGAdapter
 from .adapters.pyformat import PyFormatAdapter
 from .adapters.mysql import BrokenMySQLAdapter
 from .adapters.generic import GenericAdapter
 from .adapters.sqlite3 import SQLite3Adapter
 from .adapters.pg8000 import Pg8000Adapter
 from .adapters.apsw import APSWAdapter
-from .exceptions import SQLLoadException
+from .utils import SQLLoadException
 from .queries import Queries
 from .query_loader import QueryLoader
 from .types import DriverAdapterProtocol
@@ -22,11 +21,12 @@ _ADAPTERS: Dict[str, Callable[..., DriverAdapterProtocol]] = {
     "aiosqlite": AioSQLiteAdapter,  # type: ignore
     "apsw": APSWAdapter,
     "asyncpg": AsyncPGAdapter,  # type: ignore
+    "mariadb": BrokenMySQLAdapter,
     "mysqldb": BrokenMySQLAdapter,
     "mysql-connector": PyFormatAdapter,
     "pg8000": Pg8000Adapter,
-    "psycopg": PsycoPGAdapter,
-    "psycopg2": PsycoPGAdapter,
+    "psycopg": PyFormatAdapter,
+    "psycopg2": PyFormatAdapter,
     "pygresql": PyFormatAdapter,
     "pymysql": BrokenMySQLAdapter,
     "sqlite3": SQLite3Adapter,
@@ -35,9 +35,9 @@ _ADAPTERS: Dict[str, Callable[..., DriverAdapterProtocol]] = {
 
 def register_adapter(name: str, adapter: Callable[..., DriverAdapterProtocol]):
     """Register or override an adapter."""
-    if name in _ADAPTERS:
+    if name.lower() in _ADAPTERS:
         log.warning(f"overriding aiosql adapter {name}")
-    _ADAPTERS[name] = adapter
+    _ADAPTERS[name.lower()] = adapter
 
 
 def _make_driver_adapter(
@@ -46,18 +46,21 @@ def _make_driver_adapter(
     """Get the driver adapter instance registered by the `driver_name`."""
     if isinstance(driver_adapter, str):
         try:
-            driver_adapter = _ADAPTERS[driver_adapter]
+            driver_adapter = _ADAPTERS[driver_adapter.lower()]
         except KeyError:
             raise ValueError(f"Encountered unregistered driver_adapter: {driver_adapter}")
-    if callable(driver_adapter):
-        if hasattr(driver_adapter, "paramstyle"):  # pragma: no cover
-            style = getattr(driver_adapter, "paramstyle")
-            if style == "pyformat":
-                driver_adapter = PyFormatAdapter
-            elif style == "named":
-                driver_adapter = GenericAdapter
-            else:
-                raise ValueError(f"Unexpected driver_adapter: {driver_adapter} ({style})")
+    # try some guessing if it is a PEP249 module
+    elif hasattr(driver_adapter, "paramstyle"):
+        style = getattr(driver_adapter, "paramstyle")  # avoid mypy warning?
+        if style == "pyformat":
+            driver_adapter = PyFormatAdapter
+        elif style == "named":
+            driver_adapter = GenericAdapter
+        else:
+            raise ValueError(f"Unexpected driver_adapter: {driver_adapter} ({style})")
+    # so, can we just call it?
+    if not callable(driver_adapter):
+        raise ValueError(f"Unexpected driver_adapter: {driver_adapter}")
 
     return driver_adapter()
 
@@ -122,6 +125,7 @@ def from_path(
     *,
     loader_cls: Type[QueryLoader] = QueryLoader,
     queries_cls: Type[Queries] = Queries,
+    ext: Tuple[str] = (".sql",),
 ):
     """Load queries from a `.sql` file, or directory of `.sql` files.
 
@@ -135,13 +139,14 @@ def from_path(
     declarations to the python classes which aiosql should use when marshaling SQL results.
     * **loader_cls** - *(optional)* Custom constructor for `QueryLoader` extensions.
     * **queries_cls** - *(optional)* Custom constructor for `Queries` extensions.
+    * **ext** - *(optional)* allowed file extensions for query files, default is `(".sql",)`
 
     **Returns:** `Queries`
 
     Usage:
 
     ```python
-    >>> queries = aiosql.from_path("./sql", "pscycopg2")
+    >>> queries = aiosql.from_path("./sql", "psycopg2")
     >>> queries = aiosql.from_path("./sql", MyDBAdapter)
     ```
     """
@@ -157,7 +162,7 @@ def from_path(
         query_data = query_loader.load_query_data_from_file(path)
         return queries_cls(adapter).load_from_list(query_data)
     elif path.is_dir():
-        query_data_tree = query_loader.load_query_data_from_dir_path(path)
+        query_data_tree = query_loader.load_query_data_from_dir_path(path, ext=ext)
         return queries_cls(adapter).load_from_tree(query_data_tree)
     else:  # pragma: no cover
         raise SQLLoadException(f"The sql_path must be a directory or file, got {sql_path}")
