@@ -1,14 +1,13 @@
-# use re2 if available.
-# FIXME strange issue on debian buster with py3.7 apache wsgi flask… loading re2 "freezes" the process
-try:
-    import re2 as re
-except ModuleNotFoundError:  # pragma: no cover
-    import re  # type: ignore
+import re
 
+# FIXME to be improved
 VAR_REF = re.compile(
-    r'(?P<dblquote>"[^"]+")|'
-    r"(?P<quote>\'[^\']*\')|"
-    r"(?P<lead>[^:]):(?P<var_name>[\w-]+)(?P<trail>[^:]?)"
+    # NOTE probably pg specific?
+    r'(?P<dblquote>"(""|[^"])+")|'
+    # FIXME mysql/mariadb use backslash escapes
+    r"(?P<quote>\'(\'\'|[^\'])*\')|"
+    # NOTE beware of overlapping re
+    r"(?P<lead>[^:]):(?P<var_name>[\w-]+)(?=[^:]?)"
 )
 """Pattern to identifies colon-variables in SQL code"""
 
